Examples
========

Dask, and therefore Coiled, are deeply integrated with the Python ecosystem. 

This list is by no means exhaustive (see `Dask Ecosystem <https://docs.dask.org/en/latest/ecosystem.html>`_), but here are some introductory examples of ways you can use Coiled to easily scale up popular tools you already use.

.. toctree::
   :maxdepth: 1
   :hidden:

   examples/prefect
   examples/dask-optuna-hpo.ipynb
   examples/dask-xgboost.ipynb
   examples/parallel-hpo-multi-cluster.ipynb
   examples/jupyterlab.ipynb
   ETL automation with GitHub Actions <https://coiled.io/blog/github-actions-s3-deploy/>
   Faster model training with scikit-learn <https://coiled.io/blog/sklearn-joblib-dask/>
   examples/mongodb.ipynb

.. panels::
   :body: text-center
   :header: text-center h5 bg-white
   :footer: border-2 bg-white

   |
   | **Workflow automation with Prefect**
   |

   .. link-button:: examples/prefect
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link
    
   ---

   |
   | **Distributed HPO with Dask and Optuna**
   |

   .. link-button:: examples/dask-optuna-hpo
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---
   
   |
   | **Scaling XGBoost with Dask**
   |

   .. link-button:: examples/dask-xgboost
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---
   
   |
   | **Parallel HPO with xgboost.dask and Optuna in Multiple Clusters**
   |

   .. link-button:: examples/parallel-hpo-multi-cluster
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   |
   | **Using Coiled with JupyterLab**
   |

   .. link-button:: examples/jupyterlab
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   |
   | **ETL automation with GitHub Actions**
   |

   .. link-button:: https://coiled.io/blog/github-actions-s3-deploy/
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   |
   | **Faster model training with scikit-learn**
   |

   .. link-button:: https://coiled.io/blog/sklearn-joblib-dask/
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---


   |
   | **Parallel read and write with MongoDB**
   |

   .. link-button:: examples/mongodb
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link
